@@ -1,7 +1,7 @@
 package App::xsum;
 
 our $DATE = '2019-09-12'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -52,13 +52,16 @@ _
         },
         algorithm => {
             schema => ['str*', in=>[qw/crc32 md5 sha1 sha224 sha256 sha384 sha512 sha512224 sha512256 Digest/]],
-            default => 'md5',
             description => <<'_',
 
 In addition to `md5`, `sha1` or the other algorithms, you can also specify
 `Digest` to use Perl's <pm:Digest> module. This gives you access to tens of
 other digest modules, for example <pm:Digest::BLAKE2> (see examples).
 
+When `--digest-args` (`-A`) is not specified, algorithm defaults to `md5`. But
+if `--digest-args` (`-A`) is specified, algorithm defaults to `Digest`, for
+convenience.
+
 _
             cmdline_aliases => {a=>{}},
         },
@@ -106,9 +109,16 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Compute MD5 digests for some files (also same as previous example, -a defaults to "Digest" when -A is specified)',
+            src => 'xsum -A MD5 *.dat',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             summary => 'Compute BLAKE2b digests for some files (requirest Digest::BLAKE2 Perl module)',
-            src => 'xsum -a Digest -A BLAKE2,blake2b *.dat',
+            src => 'xsum -A BLAKE2,blake2b *.dat',
             src_plang => 'bash',
             test => 0,
             'x.doc.show_result' => 0,
@@ -150,6 +160,8 @@ sub xsum {
 
     my %args = @_;
 
+    my $algorithm = $args{algorithm} // ($args{digest_args} ? 'Digest' : 'md5');
+
     my $num_success;
     my $envres;
     my $i = -1;
@@ -202,7 +214,7 @@ sub xsum {
                 next;
             }
             my $digest_res = File::Digest::digest_file(
-                file => $file, algorithm => $args{algorithm}, digest_args=> $args{digest_args});
+                file => $file, algorithm => $algorithm, digest_args=> $args{digest_args});
             unless ($digest_res) {
                 $envres //= [
                     500, "Some files' checksums cannot be checked"];
@@ -222,14 +234,14 @@ sub xsum {
 
             # produce checksum for file
             my $res = File::Digest::digest_file(
-                file => $file, algorithm => $args{algorithm}, digest_args=> $args{digest_args});
+                file => $file, algorithm => $algorithm, digest_args=> $args{digest_args});
             unless ($res->[0] == 200) {
                 warn "Can't checksum $file: $res->[1]\n";
                 next;
             }
             $num_success++;
             if ($args{tag}) {
-                printf "%s (%s) = %s\n", uc($args{algorithm}), $file, $res->[2];
+                printf "%s (%s) = %s\n", uc($algorithm), $file, $res->[2];
             } else {
                 printf "%s  %s\n", $res->[2], $file;
             }
@@ -256,7 +268,7 @@ App::xsum - Compute and check file checksums/digests (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.004 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
+This document describes version 0.005 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
 
 =head1 SYNOPSIS
 
@@ -289,12 +301,16 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<algorithm> => I<str> (default: "md5")
+=item * B<algorithm> => I<str>
 
 In addition to C<md5>, C<sha1> or the other algorithms, you can also specify
 C<Digest> to use Perl's L<Digest> module. This gives you access to tens of
 other digest modules, for example L<Digest::BLAKE2> (see examples).
 
+When C<--digest-args> (C<-A>) is not specified, algorithm defaults to C<md5>. But
+if C<--digest-args> (C<-A>) is specified, algorithm defaults to C<Digest>, for
+convenience.
+
 =item * B<check> => I<bool>
 
 Read checksum from files and check them.
